#!/bin/sh  
#********************************************************************************
# Copyright  [2014] Unpublished Work of Novell, Inc. All Rights Reserved.
# THIS IS AN UNPUBLISHED WORK OF NOVELL, INC.  IT CONTAINS NOVELL'S CONFIDENTIAL, 
# PROPRIETARY, AND TRADE SECRET INFORMATION. NOVELL RESTRICTS THIS WORK TO NOVELL 
# EMPLOYEES WHO NEED THE WORK TO PERFORM  THEIR  ASSIGNMENTS AND TO THIRD PARTIES 
# AUTHORIZED BY NOVELL IN WRITING. THIS WORK MAY NOT BE USED,COPIED, DISTRIBUTED, 
# DISCLOSED,ADAPTED,PERFORMED,DISPLAYED,COLLECTED,COMPILED,  OR  LINKED   WITHOUT 
# NOVELL'S PRIOR WRITTEN CONSENT.  USE  OR  EXPLOITATION  OF  THIS  WORK  WITHOUT 
# AUTHORIZATION COULD SUBJECT  THE  PERPETRATOR  TO CRIMINAL AND  CIVIL LIABILITY
#********************************************************************************
file_version="1.0.0"
script_filename=$0

export PATH=$PATH:/sbin:/usr/sbin:/usr/local/sbin:/root/bin:/usr/local/bin:/usr/bin:/bin:/opt/novell/eDirectory/bin:/opt/novell/eDirectory/sbin:/opt/novell/bin:/opt/novell/bin:/opt/novell/migration/sbin

FILE="$1"
NDS_CONFIG="/opt/novell/eDirectory/bin/ndsconfig"
LDAP_ADMIN_CONTEXT="cn=admin,o=iPrintAppliance"
ERR_LOG="/var/opt/novell/log/iprintmobile/csvimport.log"
TEMP_CSV_FILE="/tmp/tmp-csv-file.csv"

args=$@
total=$(echo $args | awk 'END { print NF }')
tree_name=$($NDS_CONFIG get n4u.base.tree-name | grep "n4u.base.tree-name" | awk -F"=" '{print $2}')
server_ipaddress=$(/sbin/ifconfig | grep 'inet addr:' | cut -d: -f2 | awk '{ print $1}' | grep -v "127")
passwd=$2


#error Codes
SUCCESS=0
FILE_NOT_FOUND=1
FILE_NOT_READABLE=2
PAR_PA_CREATION_FAILED=3
NON_ROOT_USER=4
GENERAL_ERROR=5
FULL_PA_CREATION_FAILED=6

# Lets do all comparison case-insensitive
shopt -s nocasematch

usage()
{
	echo
	echo "Usage ->  /opt/novell/iprintmobile/bin/csv_printer_import.sh <inputPrinterAttributesFile> <admin pwd>"
	exit 1
}

trim() {
	local var=$@
	# remove leading whitespace characters
	var="${var#"${var%%[![:space:]]*}"}"  
	# remove trailing whitespace characters
	var="${var%"${var##*[![:space:]]}"}" 
	echo -n "$var"
}

getField()
{
    temp=$(echo $1 | cut -d ',' -f$2)
    trim $temp
}

splitLine()
{
	line="$1"
	printer_name=$(getField $line 1)
	printer_ipaddress=$(getField $line 2)
	location=$(getField $line 3)
	description=$(getField $line 4)

	win95_98_driver=$(getField $line 5)
	winnt_driver=$(getField $line 6)
	win2k_driver=$(getField $line 7)
	winxp_driver=$(getField $line 8)
	linux_driver=$(getField $line 9)
	mac_driver=$(getField $line 10)
	vista32_driver=$(getField $line 11)
	vista64_driver=$(getField $line 12)
	win732_driver=$(getField $line 13)
	win764_driver=$(getField $line 14)
	win832_driver=$(getField $line 15)
	win864_driver=$(getField $line 16)
	win1032_driver=$(getField $line 17)
	win1064_driver=$(getField $line 18)
	

	is_directPrinting_enabled=$(getField $line 19)
	is_secure=$(getField $line 20)
	is_Audit_enabled=$(getField $line 21)
	portType=$(getField $line 22)
	port=$(getField $line 23)

	if [ "$portType" = "" ];then
		portType="LPR"
	fi	

	#disable Auditing and Direct Printing if both are enabled: This is done by iprintman command line tool also.
	if [[ "$is_directPrinting_enabled" == [yY][eE][sS] ]] || [[ "$is_directPrinting_enabled" == [yY] ]];then
		if [[ "$is_Audit_enabled" == [yY][eE][sS] ]] || [[ "$is_Audit_enabled" == [yY] ]];then
			is_Audit_enabled="no"
			is_directPrinting_enabled="no"
			echo "Audit and Direct Printing can not be enabled together. Disabling both" | tee -a ${ERR_LOG}
		fi
	fi

	# constructing the gateway load String
	if [[ "$portType" == [rR][aA][wW] ]];then
		if echo "$port" | egrep -E '[0-9]'
		then
			gatewayLoadString="iprintgw PORT=RAW HOSTNAME=${printer_ipaddress}:$port"
		else
			gatewayLoadString="iprintgw PORT=RAW HOSTNAME=${printer_ipaddress}"
		fi
	else
		gatewayLoadString="iprintgw PORT=LPR HOSTNAME=${printer_ipaddress} PRINTERNAME=PASSTHROUGH"
	fi
}

processLine()
{
	line="$1"
	splitLine $line
	if validateEntries
	then
		createPrinters
	else	
		echo "Validation Failed for the printer : ${printer_name} " | tee -a ${ERR_LOG}
		failedPrinterCounter=$((failedPrinterCounter+1))
	fi
}

associateDriver()
{
	driverName=$1
	driverParam=$2
	if [ -z "${driverName}" ] || [ -z "${driverParam}" ]; then
		return
	fi

	echo "Associating ${driverName}  ${driverParam} to ${printer_name}" | tee -a ${ERR_LOG}
	if [ "$driverName" != "" ];then
		driver_association=$(iprintman printer -m ${printer_name}  --${driverParam} "${driverName}"  -u "$LDAP_ADMIN_CONTEXT" -P $passwd --accept-cert | tee -a ${ERR_LOG}| grep "attributes modified successfully")
		if [ "$driver_association" != "" ];then
			echo "$printer_name association is successfully done with the driver $driverName"  | tee -a ${ERR_LOG}
		else
			echo "$printer_name association with the driver $driverName failed" | tee -a ${ERR_LOG}
		fi
	fi
}

validateEntries()
{
	#validates printer name
	echo "validating printer_name : "$printer_name " and IP address: "$printer_ipaddress
	if [ "$printer_name" = "" ];then
		echo "no printer name specified" | tee -a ${ERR_LOG}
		return 1;
	fi

	if echo "$printer_name" | egrep -E '[+#\\/=&?%!;,]'
	then
		echo "Invalid name : $printer_name" | tee -a ${ERR_LOG}
		return 1;
	fi
	#validates IPAddress
	if echo "$printer_ipaddress" | egrep -E '[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}'
	then
		VALID_IP_ADDRESS="$(echo $printer_ipaddress | awk -F'.' '$1 <=255 && $2 <= 255 && $3 <= 255 && $4 <= 255')"
		if [ ! -z "$VALID_IP_ADDRESS" ]
		then
			return 0;
		fi
		echo "Invalid IP : $printer_ipaddress" |  tee -a ${ERR_LOG}
	fi
	return 1;
}

createPrinters()
{
	CREATEPA_FAILED=1;
	echo | tee -a ${ERR_LOG}
	echo "Creating printer : ${printer_name} " | tee -a ${ERR_LOG}
	createPrintercmd="/opt/novell/bin/iprintman printer -c \"${printer_name}\" -u "$LDAP_ADMIN_CONTEXT" -P $passwd   --gateway-load-string \"$gatewayLoadString\" -s ${server_ipaddress} --accept-cert  "
	if [[ "$is_Audit_enabled" == [yY][eE][sS] ]] || [[ "$is_Audit_enabled" == [yY] ]];then
		echo "Audit : "$is_Audit_enabled | tee -a ${ERR_LOG}
		createPrintercmd="$createPrintercmd --audit-enabled yes"
	fi
	if [[ "$is_secure" == [yY][eE][sS] ]] || [[ "$is_secure" == [yY] ]];then
		echo "Secure : "$is_secure | tee -a ${ERR_LOG}
		createPrintercmd="$createPrintercmd --ssl-required yes"
	fi
	if [[ "$is_directPrinting_enabled" == [yY][eE][sS] ]] || [[ "$is_directPrinting_enabled" == [yY] ]];then
		echo "Direct printing : "$is_directPrinting_enabled | tee -a ${ERR_LOG}
		createPrintercmd="$createPrintercmd --direct-print-enabled yes"
	fi
	if [[ "$location" != "" ]];then
		echo "Location : "$location | tee -a ${ERR_LOG}
		createPrintercmd="$createPrintercmd --location \"$location\" "
	fi
	if [[ "$description" != "" ]];then
		echo "Description : "$description | tee -a ${ERR_LOG}
		createPrintercmd="$createPrintercmd --description \"$description\" "
	fi

	printerSuccess=`LC_ALL=en_US.UTF-8 eval $createPrintercmd | tee -a ${ERR_LOG} | grep "Printer created successfully" `
	if [ "${printerSuccess}" = ""  ]; then
		#printer Creation Failed
		echo -e "Printer ${printer_name} failed to get created  " | tee -a ${ERR_LOG}
		failedPrinterCounter=$((failedPrinterCounter+1))
		return $CREATEPA_FAILED;
	fi
	echo -e "Printer ${printer_name} created Successfully  " | tee -a ${ERR_LOG}

	associateDriver   "$win95_98_driver" 	"driver-win9x"
	associateDriver   "$winnt_driver" 	"driver-winnt"
	associateDriver   "$win2k_driver" 	"driver-win2k"
	associateDriver   "$winxp_driver" 	"driver-winxp"
	associateDriver   "$vista32_driver" 	"driver-vista32"
	associateDriver   "$vista64_driver" 	"driver-vista64"
	associateDriver   "$win732_driver" 	"driver-win732"
	associateDriver   "$win764_driver" 	"driver-win764"
	associateDriver   "$win832_driver" 	"driver-win832"
	associateDriver   "$win864_driver" 	"driver-win864"
	associateDriver   "$win1032_driver" 	"driver-win1032"
	associateDriver   "$win1064_driver" 	"driver-win1064"
	associateDriver   "$linux_driver" 	"driver-linux"
	associateDriver   "$mac_driver" 	"driver-mac"
	return 0;
}

readCsvFile()
{
	FILE="$1"
	printerCount=0
	#make sure file exist and readable
	if [ ! -f $FILE ]; then
		echo "$FILE : does not exists" | tee -a ${ERR_LOG}
		exit $FILE_NOT_FOUND
	elif [ ! -r $FILE ]; then
		echo "$FILE: can not read"  | tee -a ${ERR_LOG}
		exit $FILE_NOT_READABLE
	elif [ ! -s $FILE ]; then
		echo "$FILE : File is empty" | tee -a ${ERR_LOG}
		exit $SUCCESS
	fi

	BAKIFS=$IFS
	IFS=$(echo -en "\n\b")
	exec 3<&0
	exec 0<$FILE

	#egrep -v '^#' $FILE | egrep -v '^$' |
	while read line
	do
		# Skip blank lines
		if [[ ! -z "$line" ]]; then
			# Skip commented lines
			if echo "$line" | egrep -v ^[\#\$] ;then
				processLine $line
				printerCount=$((printerCount+1))
			fi
		fi
	done < $FILE
	exec 0<&3
	echo " Out of  $printerCount Printers , $failedPrinterCounter printers failed to get created " | tee -a ${ERR_LOG}
	if [ $failedPrinterCounter -eq $printerCount ] ;then
		echo " Exiting with Exit Code : $FULL_PA_CREATION_FAILED " | tee -a ${ERR_LOG}
		exit $FULL_PA_CREATION_FAILED
	fi
	if [ $failedPrinterCounter -ne 0 ];then
		#PAR_PA_CREATION_FAILED=$((0-failedPrinterCounter))
		echo "Exiting with Exit Code : $PAR_PA_CREATION_FAILED " | tee -a ${ERR_LOG}
		exit $PAR_PA_CREATION_FAILED;
	fi

	IFS=$BAKIFS
	echo " Exiting with Exit Code : $SUCCESS " | tee -a ${ERR_LOG}
	exit $SUCCESS
}

changeEncoding()
{
	# Convert csv file to utf-8. If can't log a message
	from=$(file -ib $FILE | cut -f2 -d=)
	if [ -z $from ]; then
		echo "Not able to detect encoding for input file. This may cause issues in those entries which uses non-english or extended character set" | tee -a ${ERR_LOG}
		return 1
	fi
	echo "${FILE} current encoding: "$from | tee -a ${ERR_LOG}
	iconv -f $from -t UTF-8 $FILE -o $TEMP_CSV_FILE
	if [ $? -ne 0 ]; then
		echo "Failed to convert to utf-8 encoding. " | tee -a ${ERR_LOG}
		return 1
	fi	
	echo "Copied to ${TEMP_CSV_FILE} and converted to: "$(file -ib $TEMP_CSV_FILE | cut -f2 -d=) | tee -a ${ERR_LOG}
	return 0
}

#main
printer_name=""
printer_ipaddress=""
location=""
win95_98_driver=" "
winnt_driver=" "
win2k_driver=" "
winxp_driver=" "
linux_driver=" "
mac_driver=" "
vista32_driver=" "
vista64_driver=" "
win732_driver=" "
win764_driver=" "
win832_driver=" "
win864_driver=" "
win1032_driver=" "
win1064_driver=" "

rawPort="9100"
is_secure=" "
is_Audit_enabled=" "
is_directPrinting_enabled=" "
portType="LPR"
gatewayLoadString=" "
failedPrinterCounter=0

## check for root user
if [ "`id -u`" -ne 0 ];  then
	echo "You must be root to run this script!" | tee -a ${ERR_LOG}
	echo ""
	exit $NON_ROOT_USER;
fi

#check for number of arguments
if [ $total -ne 2 ];then
	usage
	exit $GENERAL_ERROR
fi

# Log script name and script version
echo "script file name: ${script_filename} version: ${file_version}" >> ${ERR_LOG}

# Convert csv file to utf-8. If can't log a message
if changeEncoding
then
	#read printter attributes from csv file and create printers
	readCsvFile $TEMP_CSV_FILE
else
	readCsvFile $FILE
fi
