#!/bin/sh  
#********************************************************************************
# Copyright  [2014] Unpublished Work of Novell, Inc. All Rights Reserved.
# THIS IS AN UNPUBLISHED WORK OF NOVELL, INC.  IT CONTAINS NOVELL'S CONFIDENTIAL, 
# PROPRIETARY, AND TRADE SECRET INFORMATION. NOVELL RESTRICTS THIS WORK TO NOVELL 
# EMPLOYEES WHO NEED THE WORK TO PERFORM  THEIR  ASSIGNMENTS AND TO THIRD PARTIES 
# AUTHORIZED BY NOVELL IN WRITING. THIS WORK MAY NOT BE USED,COPIED, DISTRIBUTED, 
# DISCLOSED,ADAPTED,PERFORMED,DISPLAYED,COLLECTED,COMPILED,  OR  LINKED   WITHOUT 
# NOVELL'S PRIOR WRITTEN CONSENT.  USE  OR  EXPLOITATION  OF  THIS  WORK  WITHOUT 
# AUTHORIZATION COULD SUBJECT  THE  PERPETRATOR  TO CRIMINAL AND  CIVIL LIABILITY
#********************************************************************************
file_version="1.0.1"

# Get start time of this script. Just for performance evaluation
START_TIME=$(date +%s)

export PATH=$PATH:/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/sbin:/root/bin:/usr/local/bin

# Today's date
currentdate=$(date +"%m/%d/%y")
# Today's date converted in mm/dd/yyyy format
convertedCurrentDate=$(date -d $(date +"%m/%d/%Y") '+%s')

# Look into file for this date or later and start reading from that point till today
someTimeBack=$((365*24*60*60))
startDate=$((convertedCurrentDate - someTimeBack))

# Used to increase date by a day
aDay=$((24*60*60))

# OUTPUTFILE, will hold the final result and can be consumed by MC
OUTPUTFILE=/tmp/audit_data_output.csv

# Audit.csv path
AUDIT_CSV=/var/opt/novell/iprintmobile/audit.csv

TEMP_FILE=$(/bin/mktemp)
TMP_AUDIT_FILE=$(/bin/mktemp)
#DATE=$(date '+%m/%d/%y')
headers="date,"
values=$currentdate","
DAYS="365"

# Return codes
SUCCESS=0
RETURN_CODE=$SUCCESS

# Search for the date in audit.csv file.
# We'll start with one year old date (365 days)
# and if not found, increase the date by one day (aDay) and search for that
# When the date found, we'll put the data starting from that line till end of 
# file into a temporary file. This temporary file will then be used to gather 
# the required information.
createTempFile()
{
	# Till we get data in temporary file or we cross today's date
	while [ ! -s ${TMP_AUDIT_FILE} ] && [ ${startDate} -le ${convertedCurrentDate} ]
	do
		# Convert date to mm/dd/yyyy format. This format is used in audit.csv by
		# mobile server writes date in this format. Any change in this format 
		# from mobile server may affect the behavior. 
		DAT=$(date -d @${startDate} +"%m/%d/%Y") 
		#echo $DAT

		# Escape slash (/) in DAT, so that it'll not cause any problem in 'sed' command
		DATE=$(echo $DAT | sed 's/\//\\\//g')
		#echo "searching date" $DATE

		# Comamnd and options to be used for sed. 
		# This will take data from 'the line where DATE matches' to 'till end of file'.
		COMMAND="/"${DATE}"/,\$p"
		#echo $COMMAND

		# Search and if found, Write the data in a temporary file
		sed -n $COMMAND ${AUDIT_CSV} > ${TEMP_FILE}

		# Convert file to lower case
		tr '[:upper:]' '[:lower:]' < ${TEMP_FILE} > ${TMP_AUDIT_FILE}	

		# If date didn't match, we'll try next day
		((startDate += aDay))
	done
}

# Fetch the required values from various files.
getValues()
{
	# col #2
	# Get the print manager's name and then reach to the padbtxt.xml file of that Print manager.
	printManager=$(ls -al /etc/opt/novell/iprint/conf/ipsmd.conf | cut -d/ -f13 | sed 's/.ipsmd.conf//')
	totalPrinters=$(cat /var/opt/novell/iprint/$printManager.psm/padbtxt.xml | grep "<printer>" | wc -l)
	headers=${headers}"totalPrinters,"
	values=${values}$totalPrinters","

	# col #3
	totalEntries=$(cat /var/opt/novell/iprintmobile/iprintmobiledb.xml | grep "</printer>" | wc -l)
	# <job> entry in xml file will also have <printer> sub-tag. So to remove duplicate calculation
	# subtract all <job> tags
	jobEntries=$(cat /var/opt/novell/iprintmobile/iprintmobiledb.xml | grep "<job id" | wc -l)
	mobileEnabledPrinters=$((totalEntries - jobEntries))
	headers=${headers}"mobilePrinters,"
	values=${values}$mobileEnabledPrinters","

	# col #4
	airPrintEnabledPrinters=$(ls /etc/avahi/services/ | wc -l)
	airPrintEnabledPrinters=$((airPrintEnabledPrinters - 2))
	headers=${headers}"airPrintPrinters,"
	values=${values}$airPrintEnabledPrinters","

	# col #5
	tmp_eDirUsers=$(/opt/novell/eDirectory/bin/ldapsearch -LLL  -s sub "(objectClass=user)" | grep dn: | wc -l)
	# Subtract 2 users: admin and serviceuser
	eDirUsers=$((tmp_eDirUsers-2))
	headers=${headers}"eDirUsers,"
	values=${values}$eDirUsers","

	# col #6
	# We'll consider admin, ADMIN, cn=admin,o=iPrintAppliance and CN=ADMIN,O=IPRINTAPPLIANCE as one user
	# Input file is already converted to lower case by now, so lets just concentrate on converting FDN to CN only and then count
	totalUniqueMobileUsers=$(cat ${TMP_AUDIT_FILE} | cut -f3 -d, | cut -f2 -d= | tr ' ' , | rev | cut -f2-20 -d, | rev | tr ',' ' '| sort | uniq | wc -l)
	headers=${headers}"totalUniqueMobileUsers,"
	values=${values}$totalUniqueMobileUsers","

	# col #7
	uniqueEmailUsers=$(cat  ${TMP_AUDIT_FILE} | cut -f3 -d, | perl -wne'while(/[\w\.]+@[\w\.]+/g){print "$&\n"}'| sort| uniq | wc -l)
	headers=${headers}"uniqueEmailUsers,"
	values=${values}$uniqueEmailUsers","

	# col #8
	mobileIppUsers=$((totalUniqueMobileUsers - uniqueEmailUsers))
	headers=${headers}"mobileIppUsers,"
	values=${values}$mobileIppUsers","
}

# If audit.csv is not yet created, no need to look for that file.
# In this case, all the values which we are reading from that file
# will be zero (0)
if [ -f ${AUDIT_CSV} ]; then
	# Search for the date starting $startDate
	createTempFile
fi

# Collect values from various files including the temporary file (TMP_AUDIT_FILE)
getValues

echo $headers > ${OUTPUTFILE}
echo $values >> ${OUTPUTFILE}

#Remove temporary file
rm ${TMP_AUDIT_FILE} ${TEMP_FILE}

END_TIME=$(date +%s)
echo "Time taken " $((END_TIME - START_TIME))
exit $RETURN_CODE
