#!/bin/sh  
#********************************************************************************
# Copyright  [2014] Unpublished Work of Novell, Inc. All Rights Reserved.
# THIS IS AN UNPUBLISHED WORK OF NOVELL, INC.  IT CONTAINS NOVELL'S CONFIDENTIAL, 
# PROPRIETARY, AND TRADE SECRET INFORMATION. NOVELL RESTRICTS THIS WORK TO NOVELL 
# EMPLOYEES WHO NEED THE WORK TO PERFORM  THEIR  ASSIGNMENTS AND TO THIRD PARTIES 
# AUTHORIZED BY NOVELL IN WRITING. THIS WORK MAY NOT BE USED,COPIED, DISTRIBUTED, 
# DISCLOSED,ADAPTED,PERFORMED,DISPLAYED,COLLECTED,COMPILED,  OR  LINKED   WITHOUT 
# NOVELL'S PRIOR WRITTEN CONSENT.  USE  OR  EXPLOITATION  OF  THIS  WORK  WITHOUT 
# AUTHORIZATION COULD SUBJECT  THE  PERPETRATOR  TO CRIMINAL AND  CIVIL LIABILITY
#********************************************************************************
file_version="1.0.0"

if [ "$(whoami)" != 'root' ]; then
		echo "$0 must be run as root."
		exit 1;
fi

logLocation=/var/opt/novell/log/iprintmobile
hashVal=`hostname -f | md5sum | awk '{print $1}'`
outputfile=iprint-appliance_stats_${hashVal}_`date +%F_%T`
outputfn=${logLocation}/${outputfile}

headers=""
values=""

echo "Gathering Anonymous Stats . . ."
if [ -f /etc/Novell-VA-release ]; then
	applianceVersion=`grep -i 'version' /etc/Novell-VA-release  | cut -f2 -d'='`
else
	applianceVersion="unknown"
fi
headers=${headers}"ApplianceVersion,"
values=${values}$applianceVersion","

slesVersion=`grep VERSION /etc/SuSE-release | awk '{ print $(NF) }' | tr -d ','`
slesPatch=`grep PATCHLEVEL /etc/SuSE-release | awk '{ print $(NF) }' | tr -d ','`
headers=${headers}"SLESVersion,"
values=${values}"SLES"$slesVersion"SP"$slesPatch","

oesVersion=`grep VERSION /etc/novell-release | awk '{ print $(NF) }' | tr -d ','`
oesPatch=`grep PATCHLEVEL /etc/novell-release | awk '{ print $(NF) }' | tr -d ','`
headers=${headers}"OESVersion,"
values=${values}"OES"$oesVersion"SP"$oesPatch","

procCount=`cat /proc/cpuinfo | grep processor | wc -l | tr -d ','`
headers=${headers}"CPUCount,"
values=${values}$procCount","

kbMemory=`cat /proc/meminfo | grep "MemTotal" | awk {'print $2'} | tr -d ','`
headers=${headers}"SYSKBMemory,"
values=${values}"$kbMemory,"

kbMemoryFree=`cat /proc/meminfo | grep "MemFree" | awk {'print $2'} | tr -d ','`
headers=${headers}"SYSKBMemoryFree,"
values=${values}"$kbMemoryFree,"

sysType=`cat /sys/class/dmi/id/sys_vendor | tr -d ','`
headers=${headers}"SYSType,"
values=${values}"$sysType,"

printManager=`ls -al /etc/opt/novell/iprint/conf/ipsmd.conf | cut -d/ -f13 | sed 's/.ipsmd.conf//'`
totalPrinters=`cat /var/opt/novell/iprint/$printManager.psm/padbtxt.xml | grep "<printer>" | wc -l`
headers=${headers}"TotalPrinters,"
values=${values}$totalPrinters","

mobileEnabledPrinters=`cat /var/opt/novell/iprintmobile/iprintmobiledb.xml | grep "</printer>" | wc -l`
headers=${headers}"MobilePrinters,"
values=${values}$mobileEnabledPrinters","

airPrintEnabledPrinters=`ls /etc/avahi/services/ | wc -l`
airPrintEnabledPrinters=`expr $airPrintEnabledPrinters - 2`
headers=${headers}"AirPrintPrinters,"
values=${values}$airPrintEnabledPrinters","

securePrinters=`cat /var/opt/novell/iprint/$printManager.psm/padbtxt.xml | grep "<security_enabled>1</security_enabled>" | wc -l`
headers=${headers}"SecurePrinters,"
values=${values}$securePrinters","

directPrinting=`cat /var/opt/novell/iprint/$printManager.psm/padbtxt.xml | grep "<directprintenabled>1</directprintenabled>" | wc -l`
headers=${headers}"DirectPrinting,"
values=${values}$directPrinting","

autoDriverUpdate=`cat /var/opt/novell/iprint/$printManager.psm/padbtxt.xml | grep "<allowdriverupdateenabled>1</allowdriverupdateenabled>" | wc -l`
headers=${headers}"AutoDriverProfileUpdate,"
values=${values}$autoDriverUpdate","

auditEnabled=`cat /var/opt/novell/iprint/$printManager.psm/padbtxt.xml | grep "<auditflag>1</auditflag>" | wc -l`
headers=${headers}"AuditEnabledPrinters,"
values=${values}$auditEnabled","

lprEnabled=`cat /var/opt/novell/iprint/$printManager.psm/padbtxt.xml | grep "<lprenabled>1</lprenabled>" | wc -l`
headers=${headers}"LPREnabled,"
values=${values}$lprEnabled","

accountingNotEnabled=`cat /var/opt/novell/iprint/$printManager.psm/padbtxt.xml | grep "<accountingloadstring></accountingloadstring>" | wc -l`
totalAccounting=`cat /var/opt/novell/iprint/$printManager.psm/padbtxt.xml | grep "</accountingloadstring>" | wc -l`
accountingEnabled=`expr $totalAccounting - $accountingNotEnabled`
headers=${headers}"Accounting,"
values=${values}$accountingEnabled","

accountingLoadString=$(grep -oPm1 "(?<=<accountingloadstring>)[^<]+" /var/opt/novell/iprint/$printManager.psm/padbtxt.xml)
if [ -z "${accountingLoadString}" ]; then
	accountingLoadString="None"
fi
headers=${headers}"AccountingModule,"
values=${values}$accountingLoadString","

renderers=`cat /var/opt/novell/iprintmobile/iprintmobiledb.xml | grep "</renderer" | wc -l`
headers=${headers}"Renderers,"
values=${values}$renderers","

eDirUsers=$(/opt/novell/eDirectory/bin/ldapsearch -LLL  -s sub "(objectClass=user)" | grep dn: | wc -l)
headers=${headers}"eDirUsers,"
values=${values}$eDirUsers","

emailUsers=`cat /var/opt/novell/iprintmobile/iprintmobiledb.xml | grep "</user>"  | wc -l`
headers=${headers}"eMailUsers,"
values=${values}$emailUsers","

emailJobs=`grep -E -o "\b[a-zA-Z0-9.-._]+@[a-zA-Z0-9.-]+\.[a-zA-Z0-9.-]+\b" /var/opt/novell/iprintmobile/audit.csv | wc -l`
headers=${headers}"emailJobs,"
values=${values}$emailJobs","

mobileIPPJobs=`grep localjob /var/opt/novell/iprintmobile/audit.csv | wc -l`
headers=${headers}"mobileIPPJobs"
values=${values}$mobileIPPJobs

echo "Deleting the last submitted file."
rm `find ${logLocation}/iprint-appliance_stats*`
echo "Done"

# This file will be retained till the next run. 
# Next run will delete this file and create new one.
echo "Creating new file."
touch $outputfn
echo $headers | tr -d ' ' | tr -d '"' >> $outputfn
echo $values | tr -d ' '  >> $outputfn

echo "Done"

echo "Compressing Anonymous Stats . . ."
gzip $outputfn
echo "Done"

echo "Sending Anonymous Stats . . ."
ftp -n -v productfeedback.novell.com << EOT
bin
user anonymous ''
prompt
cd stats
cd iprint-appliance
put "${outputfn}.gz" "${outputfile}.gz"
bye
EOT
sleep 1
echo "Done"

#echo $headers
#echo $values


