#!/bin/sh
#********************************************************************************
# Copyright © [2016] Unpublished Work of Novell, Inc. All Rights Reserved.
# THIS IS AN UNPUBLISHED WORK OF NOVELL, INC.  IT CONTAINS NOVELL'S CONFIDENTIAL,
# PROPRIETARY, AND TRADE SECRET INFORMATION. NOVELL RESTRICTS THIS WORK TO NOVELL
# EMPLOYEES WHO NEED THE WORK TO PERFORM  THEIR  ASSIGNMENTS AND TO THIRD PARTIES
# AUTHORIZED BY NOVELL IN WRITING. THIS WORK MAY NOT BE USED,COPIED, DISTRIBUTED,
# DISCLOSED,ADAPTED,PERFORMED,DISPLAYED,COLLECTED,COMPILED,  OR  LINKED   WITHOUT
# NOVELL'S PRIOR WRITTEN CONSENT.  USE  OR  EXPLOITATION  OF  THIS  WORK  WITHOUT
# AUTHORIZATION COULD SUBJECT  THE  PERPETRATOR  TO CRIMINAL AND  CIVIL LIABILITY
#********************************************************************************
Version="3.0"

DATA=""
COMPONENT=('Mobile Server')
PRODUCT="iPrint"
VERSION=$(cat /etc/Novell-VA-release | grep version | cut -d= -f2)

LOG_ENABLED="no"
logInfo()
{
	if [ "${LOG_ENABLED}" == "yes" ]; then
		echo $1
	fi
}

# Input: Key for which you need value
# Return: Value of the key from credstore.conf
getValueFromCredStore()
{
    /usr/bin/base64 -di  /etc/opt/novell/iprintmobile/conf/credstore.conf | grep $1 | cut -f2 -d\> | cut -f1 -d\<
}

HOSTNAME=$(hostname -i)
USERNAME=$(getValueFromCredStore edir.username)
PASSWORD=$(getValueFromCredStore edir.password) 
TELEMETRY_DETAILS=$(curl -k -s --user ${USERNAME}:${PASSWORD} https://${HOSTNAME}/iprint/api/telemetry)
IFS=','
array=( $TELEMETRY_DETAILS )

getData() 
{
	IFS=':' read dummy totalPrinters <<< "${array[0]}"
	logInfo "Total printers "$totalPrinters
	DATA=("Total_Printers:$totalPrinters")

	IFS=':' read dummy mobile_enabled_printers <<< "${array[1]}"
	logInfo "Mobile enabled printers "$mobile_enabled_printers
	DATA=("${DATA[@]}" "Mobile_Enabled_Printers:$mobile_enabled_printers")

	IFS=':' read dummy mdns_enabled_printers <<< "${array[2]}"
	logInfo "AirPrint Enabled : "$mdns_enabled_printers
	DATA=("${DATA[@]}" "AirPrint_Enabled_Printers:$mdns_enabled_printers")

	tmp_eDirUsers=$(/opt/novell/eDirectory/bin/ldapsearch -LLL  -s sub "(objectClass=user)" | grep dn: | wc -l)
	# Subtract 2 users: admin and serviceuser
	eDirUsers=$((tmp_eDirUsers-2))
	logInfo "eDir users "$eDirUsers
	DATA=("${DATA[@]}" "eDir_Users:$eDirUsers")

	IFS=':' read dummy securePrinters <<< "${array[3]}"
	logInfo "Secure Printers: "$securePrinters
	DATA=("${DATA[@]}" "Secure_Printers:$securePrinters")

	IFS=':' read dummy totalWalkupPrinters <<< "${array[4]}"
	logInfo "Walkup Printers:"$totalWalkupPrinters
	DATA=("${DATA[@]}" "Walkup_Printers:$totalWalkupPrinters")

	IFS=':' read dummy mobileEnabledWalkupPrinters <<< "${array[5]}"
	logInfo "Mobile Enabled Walkup Printers: "$mobileEnabledWalkupPrinters
	DATA=("${DATA[@]}" "Mobile_Enabled_Walkup_Printers:$mobileEnabledWalkupPrinters")
	
	IFS=':' read dummy airPrintCapablePrinters <<< "${array[6]}"
	logInfo "AirPrint Capable Printers: "$airPrintCapablePrinters
	DATA=("${DATA[@]}" "AirPrint_Capable_Printers:$airPrintCapablePrinters")
	
	IFS=':' read dummy ippPrinters <<< "${array[7]}"
	logInfo "Ipp Printers: "$ippPrinters
	DATA=("${DATA[@]}" "Ipp_Printers:$ippPrinters")

	IFS=':' read dummy renderers <<< "${array[8]}"
	logInfo "Remote Renderers:"$renderers
	DATA=("${DATA[@]}" "Remote_Renderers:$renderers")

	# Do we use remote renderer
	CONF_FILE_ENTRY=$(cat /etc/opt/novell/iprint/conf/idsd.conf | grep IDSHostAddress | cut -d' ' -f2)
	HOSTNALE=$(hostname -f)
	if [ "${CONF_FILE_ENTRY}" == "${HOSTNALE}" ]; then
		logInfo "Local driver store"
		DATA=("${DATA[@]}" "Remote_Driver_Store:0")
	else
		logInfo "Remote driver store"
		DATA=("${DATA[@]}" "Remote_Driver_Store:1")
	fi

	IFS=':' read dummy secureRemoteRenderers <<< "${array[9]}"
	logInfo "Secure remote renderers:${secureRemoteRenderers}"
	DATA=("${DATA[@]}" "Secure_Remote_Renderers:$secureRemoteRenderers")

	IFS=':' read dummy nonsecureRemoteRenderers <<< "${array[10]}"
	logInfo "NonSecure remote renderers:${nonsecureRemoteRenderers}"
	DATA=("${DATA[@]}" "Non_Secure_Remote_Renderers:$nonsecureRemoteRenderers")

	secondaryDiskSize=$(df -h | grep vastorage | cut -d' ' -f9 | tr -d [:alpha:])
	logInfo "Secondary disk size:${secondaryDiskSize}"
	DATA=("${DATA[@]}" "Secondary_Disk_Size_(GB):$secondaryDiskSize")

	upgradedAppliance=$([ ! -f /var/opt/novell/log/iprintmobile/restore.log ]; echo $?)
	logInfo "Upgraded Appliance:${upgradedAppliance}"
	DATA=("${DATA[@]}" "Upgraded_Appliance:$upgradedAppliance")

	if [ "$upgradedAppliance" == "0" ] ; then 
		newAppliance="1"
	else	
		newAppliance="0"
	fi
	logInfo "New Appliance:${newAppliance}"
	DATA=("${DATA[@]}" "New_Appliance:$newAppliance")
		
	IFS=':' read dummy globalEmailConfigured <<< "${array[11]}"
	logInfo "Global eMail configured:${globalEmailConfigured}"
	DATA=("${DATA[@]}" "Global_Email_Configured:$globalEmailConfigured")

	IFS=':' read dummy dummy2 <<< "${array[12]}"
	IFS='}' read privateEmailConfigured dummy <<< "${dummy2}"
	logInfo "Private eMail configured for printers:${privateEmailConfigured}"
	DATA=("${DATA[@]}" "Private_Email_Configured_For_Printers:$privateEmailConfigured")
	
	directPrinterEnabled=$(cat /var/opt/novell/iprint/print_manager.iPrintAppliance.psm/padbtxt.xml  | grep directprintenabled\>1 | wc -l)
	logInfo "Direct Printers enabled:${directPrinterEnabled}"
	DATA=("${DATA[@]}" "Direct_Printers:$directPrinterEnabled")

	auditEnabled=$(cat /var/opt/novell/iprint/print_manager.iPrintAppliance.psm/padbtxt.xml  | grep auditflag\>1 | wc -l)
	logInfo "Audit Enabled Printer:${auditEnabled}"
	DATA=("${DATA[@]}" "Audit_Enabled_Printers:$auditEnabled")

	totalPrintersIncludingWalkupPrinters=$((totalPrinters + totalWalkupPrinters))
	accountingString=$(cat /var/opt/novell/iprint/print_manager.iPrintAppliance.psm/padbtxt.xml  | grep \<accountingloadstring\>\<\/accountingloadstring\> | wc -l)
	accountingEnabledPrinters=$((totalPrintersIncludingWalkupPrinters - accountingString))
	logInfo "Accounting enabled for printers:${accountingEnabledPrinters}"
	DATA=("${DATA[@]}" "Accounting_Enabled_Printers:$accountingEnabledPrinters")

	lprEnabledPrinters=$(cat /var/opt/novell/iprint/print_manager.iPrintAppliance.psm/padbtxt.xml  | grep \<lprenabled\>1 | wc -l)
	logInfo "LPR Enabled Printers:${lprEnabledPrinters}"
	DATA=("${DATA[@]}" "LPR_Enabled_Printers:$lprEnabledPrinters")

}

sendDataToLogger()
{
	/opt/novell/telemetry-client-logger/sbin/telemetry-logger.sh -c "${COMPONENT[@]}" -p "${PRODUCT}" -v ${VERSION} metric -d "${DATA[@]}"
	status=$? 
	if [ ${status} -eq 0 ]; then
		logInfo "Success! Data send to logger successfully."
	else
		logInfo "Failed! Error occured while sending data to logger."
	fi
}
getData
#printf '%s\n' "${DATA[@]}"
sendDataToLogger


